<?php
/**
 * rafi Theme Options
 *
 * @package rafi
 * @since rafi 5.00.08
 */


/**
 * Add a menu item for the theme customizer
 *
 * @since 5.00.08
 */



/**
 * Theme customizer with real-time update
 *
 * @since 5.00.08
 */
function rafi_theme_customizer( $wp_customize ) {
	
	$wp_customize->add_section( 'rafi_color_scheme_settings', array(
		'title'       => __( 'Color Scheme', 'rafi' ),
		'priority'    => 30,
		'description' => __( 'Color scheme', 'rafi' ),
	) );

	$wp_customize->add_setting( 'rafi_color_scheme', array(
		'default'        => 'default',
		'sanitize_callback' => 'rafi_hex_color',
	) );

	$wp_customize->add_control( 'rafi_color_scheme', array(
		'label'   => __( 'Choose a color scheme', 'rafi' ),
		'section' => 'rafi_color_scheme_settings',
		'default'        => 'default',
		'type'       => 'radio',
		'choices'    => array(
		    __( 'default', 'rafi' ) => 'default',
			__( 'Blue', 'rafi' ) => 'blue',
			__( 'Red', 'rafi' ) => 'red',
			__( 'Green', 'rafi' ) => 'green',
			__( 'Gray', 'rafi' ) => 'gray',
			__( 'Brown', 'rafi' ) => 'brown',
			__( 'Pink', 'rafi' ) => 'pink',
			__( 'Black', 'rafi' ) => 'black',
			__( 'Yellow', 'rafi' ) => 'yellow',
		),
	));
		//general settings panel
	$wp_customize->add_panel( 'rafi_general', array(
		'priority'       => 10,
		'capability'     => 'edit_theme_options',
		'title'          => __( 'Rafi Font Selection', 'rafi' ),
		'description'    => __( 'Change your fonts', 'rafi' ),
	) );

	//rafi fonts

	//Prepare the array of fonts to select from
	$google_fonts = array(
		'sans-serif' => __( 'sans-serif', 'rafi' ),
		'Shadows' => __( 'Georgia', 'rafi' ),
		'Kalam' => __( 'Kalam', 'rafi' ),
		'Patrick' => __( 'Patrick Hand', 'rafi' ),
		'Neucha' => __( 'Neucha', 'rafi' ),
		'Delius' => __( 'Delius', 'rafi' ),
		'Delius_Caps' => __( 'Delius Swash Caps', 'rafi' ),
		'Caveat' => __( 'Caveat Brush', 'rafi' ),
		'Itim' => __( 'Itim', 'rafi' ),
		'Dekko' => __( 'Dekko', 'rafi' ),
	);

	$wp_customize->add_section( 'rafi_fonts_section' , array(
		'title'      => __( 'rafi Fonts', 'rafi' ),
		'priority'   => '31',
		'panel'      => 'rafi_general',
	) );
	$wp_customize->add_setting( 'paragraphs_fonts' , array(
		'default' => 'sans-serif',
		'sanitize_callback'  => 'sanitize_text_field',
	) );
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize, 'paragraphs_fonts', array(
				'label'          => __( 'Change the font of your paragraphs', 'rafi' ),
				'section'        => 'rafi_fonts_section',
				'settings'       => 'paragraphs_fonts',
				'type'           => 'select',
				'description'    => __( 'change the font of your paragraphs and buttons', 'rafi' ),
				'choices'        => $google_fonts,
			)
		)
	);
}
add_action('customize_register', 'rafi_theme_customizer');
/*****************************
sanitize color scheme
******************************/
function rafi_hex_color( $input ) {
	$valid = array( 'default', 'Blue', 'Red','Green', 'Gray', 'Brown', 'Pink', 'Black', 'Yellow' );
	if ( in_array( $input, $valid ) ) {
		return $input;
	}
	 return 'default';
}
/*****************************
rafi General Settings.
Load the fonts selected
******************************/

function rafi_change_google_fonts() {
	$fonts = array(
		'sans-serif' => array(
			'name' => __( 'sans-serif', 'rafi' ),
			'css' => 'sans-serif',
			'query' => 'sans-serif',
		),
		'Shadows' => array(
			'name' => __( 'Georgia', 'rafi' ),
			'css' => 'Georgia',
			'query' => 'Georgia',
		),
		'Kalam' => array(
			'name' => __( 'Kalam', 'rafi' ),
			'css' => 'Kalam',
			'query' => 'Kalam',
		),
		'Patrick' => array(
			'name' => __( 'Patrick Hand', 'rafi' ),
			'css' => 'Patrick Hand',
			'query' => 'Patrick+Hand',
		),
		'Neucha' => array(
			'name' => __( 'Neucha', 'rafi' ),
			'css' => 'Neucha',
			'query' => 'Neucha',
		),
		'Delius' => array(
			'name' => __( 'Delius', 'rafi' ),
			'css' => 'Delius',
			'query' => 'Delius',
		),
		'Delius_Caps' => array(
			'name' => __( 'Delius Swash Caps', 'rafi' ),
			'css' => 'Delius Swash Caps',
			'query' => 'Delius+Swash+Caps',
		),
		'Caveat' => array(
			'name' => __( 'Caveat Brush', 'rafi' ),
			'css' => 'Caveat Brush',
			'query' => 'Caveat+Brush',
		),
		'Itim' => array(
			'name' => __( 'Itim', 'rafi' ),
			'css' => 'Itim',
			'query' => 'Itim',
		),
		'Dekko' => array(
			'name' => __( 'Dekko', 'rafi' ),
			'css' => 'Dekko',
			'query' => 'Dekko',
		),
	);
	$paragraphs_font = get_theme_mod( 'paragraphs_fonts', 'Delius' );

	wp_enqueue_style( 'rafi-google-fonts', esc_url( '//fonts.googleapis.com/css?family='.$fonts[ $paragraphs_font ]['query'], 'rafi' ) );

	?>
	<style type='text/css'>
		body {font-family:<?php echo esc_html( $fonts[ $paragraphs_font ]['css'] ); ?>}
	</style>
	<?php
}
add_action( 'wp_head', 'rafi_change_google_fonts' );
/**
 * Add CSS in <head> for styles handled by the theme customizer
 *
 * @since 1.0
 */
 
function rafi_add_customizer_css() { ?>
 
	<link rel="stylesheet" href="<?php echo get_template_directory_uri();?>/css/<?php echo strtolower( get_theme_mod( 'rafi_color_scheme', 'default' ) ); ?>.css" type="text/css" media="screen">
 
<?php }
add_action( 'wp_head', 'rafi_add_customizer_css' );